Run locally:

    $ tmt -v run -a provision -h local

Run in a container:

    $ sudo dnf install tmt-provision-container
    $ tmt -v run -a provision -h container

For more info see:

- [tmt @ DevConf 2021 slides](https://static.sched.com/hosted_files/devconfcz2021/37/tmt-slides.pdf)
- [tmt docs](https://tmt.readthedocs.io)
